<?php

/**
 * @file
 * Hook provided by Comment Bonus API.
 */

 /**
  * Allows modules to provide settings for sorting comments and a callback
  * for updating the query sort.
  *
  * This creates a custom view mode for comments which can be edited by modules
  * like Display Suite. There is currently a core patch that would make it
  * easier to reuse view modes for entities: http://drupal.org/node/1154382
  *
  * @param array $settings
  *   Settings with the following keys:
  *   - label: Human readable label.
  *   - description: Human readable description.
  *   - custom settings: Whether or not to allow custom settings for display
  *                      on entity settings form.
  *   - sort: Whether new comments should be added to beginning or end of list
  *           of comments. Either DESC or ASC.
  *   - query: Callback for overriding the comment query. Receives $query as an
  *            argument.
  */
function hook_comment_bonus_api_view_mode_settings_alter(&$settings) {
  $settings['random'] = array(
    'label' => t('Random'),
    'description' => t('Sort comments randomly'),
    'custom settings' => TRUE,
    'sort' => 'DESC',
    'query' => 'random_comment_module_comment_random_query',
  );
}

/**
 * Example query callback for random_comment_module's 'random' sort order.
 */
function random_comment_module_comment_random_query(&$query) {
  $orderby = &$query->getOrderBy();
  // Reset current sorts.
  unset($orderby);
  // Sort randomly by comment id. NOTE: not tested but you get the idea.
  $orderby['c.cid'] = 'RAND()';
}
